@@ -21,8 +21,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <stdio.h>
 #include <gtk/gtk.h>
-#include <gdk_imlib.h>
-#include <gdk/gdk.h>
+/* #include <gdk_imlib.h> */
+/* #include <gdk/gdk.h> */
 
 #include "cursor.h"
 #include "globals.h"
