@@ -25,10 +25,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 int copy_opt_data();
 int calc_dimensions(struct IMAGE_OPTIONS *im_opt);
-void render_image_pixmap(GdkImlibImage *);
-int draw_big_image(GdkImlibImage *im);
+void render_image_pixmap(GdkPixbuf *);
+int draw_big_image(GdkPixbuf *im);
 void redraw_screen(int x, int y, int w, int h);
-int draw_small_image(GdkImlibImage *scale_im, int x, int y);
+int draw_small_image(GdkPixbuf *scale_im, int x, int y);
 int change_small_image(int xx, int yy);
 
 #endif
