@@ -26,6 +26,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 int file_open_dialog(char *fname);
 int file_save_dialog(char *fname);
 
-int open_image(char *fname);
+int open_image(const char *fname);
 
 #endif
