@@ -31,8 +31,12 @@ struct IMAGE_INFO {
    struct PIC_DB **matches;    /* all the other possible matches */
 };
 
-GdkImlibImage *render_image(struct IMAGE_INFO **image, int nPixW, int nPixH, int pixW, int pixH);
-void copy_image_RGB(unsigned char *, unsigned char *, int, int);
+GdkPixbuf *render_image(struct IMAGE_INFO **image, int nPixW, int nPixH, int pixW, int pixH);
+void copy_image_RGB(
+   GdkPixbuf *src,
+   GdkPixbuf *dst,
+   int col,
+   int row);
 
 
 #endif
